@@ -1,15 +1,12 @@
+( cd usr/lib ; rm -rf libacl.la )
+( cd usr/lib ; ln -sf /usr/libexec/libacl.la libacl.la )
 ( cd usr/lib ; rm -rf libacl.so.1 )
 ( cd usr/lib ; ln -sf libacl.so.1.1.0 libacl.so.1 )
 ( cd usr/lib ; rm -rf libacl.a )
 ( cd usr/lib ; ln -sf /usr/libexec/libacl.a libacl.a )
-( cd usr/lib ; rm -rf libacl.la )
-( cd usr/lib ; ln -sf /usr/libexec/libacl.la libacl.la )
 ( cd usr/lib ; rm -rf libacl.so )
 ( cd usr/lib ; ln -sf libacl.so.1 libacl.so )
+( cd usr/share/man/man3 ; rm -rf acl_extended_file_nofollow.3.gz )
+( cd usr/share/man/man3 ; ln -sf acl_extended_file.3.gz acl_extended_file_nofollow.3.gz )
 ( cd usr/libexec ; rm -rf libacl.so )
 ( cd usr/libexec ; ln -sf /usr/lib/libacl.so libacl.so )
-#%% begin initialize acl-2.2.47-i586-P1
-if [ -x /usr/bin/gtk-query-immodules-2.0 ]; then
-	/usr/bin/gtk-query-immodules-2.0 > /etc/gtk-2.0/gtk.immodules
-fi
-#%% end
